@@ -176,8 +176,8 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
         return getNextSequenceValStatement("eventsNxtId");
     }
     
-    public Integer getNextEventId() {
-        return getNextId(getNextEventIdStatement());
+    public Long getNextEventId() {
+        return getNextIdLong(getNextEventIdStatement());
     }
     
     public String getNextServiceIdStatement() {
@@ -229,11 +229,11 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
         createOutage(svc, svcLostEvent.getDbid(), new Timestamp(svcLostEvent.getTime().getTime()));
     }
 
-    public void createOutage(MockService svc, int eventId, Timestamp time) {
+    public void createOutage(MockService svc, long eventId, Timestamp time) {
         Object[] values = {
                 getNextOutageId(), // outageID
                 svc.getId(), // service ID
-                Integer.valueOf(eventId),           // svcLostEventId
+                Long.valueOf(eventId),           // svcLostEventId
                 time, // ifLostService
                };
         
@@ -245,10 +245,10 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
         resolveOutage(svc, svcRegainEvent.getDbid(), new Timestamp(svcRegainEvent.getTime().getTime()));
     }        
 
-    public void resolveOutage(MockService svc, int eventId, Timestamp timestamp) {
+    public void resolveOutage(MockService svc, long eventId, Timestamp timestamp) {
 
         Object[] values = {
-                Integer.valueOf(eventId),           // svcLostEventId
+                Long.valueOf(eventId),           // svcLostEventId
                 timestamp, // ifLostService
                 Integer.valueOf(svc.getId()) // ifServiceId
                };
@@ -262,7 +262,7 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
      */
     @Override
     public void writeEvent(Event e) {
-        Integer eventId = getNextEventId();
+        Long eventId = getNextEventId();
         
         if (e.getCreationTime() == null) {
             e.setCreationTime(new Date());
@@ -456,7 +456,7 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
                 notifyIds.add(rs.getInt(1));
             }
         };
-        loadExisting.execute(Integer.valueOf(event.getDbid()));
+        loadExisting.execute(Long.valueOf(event.getDbid()));
         return notifyIds;
     }
 
@@ -485,6 +485,10 @@ public class MockDatabase extends TemporaryDatabasePostgreSQL implements EventWr
         return getJdbcTemplate().queryForObject(nxtIdStmt, Integer.class);
     }
 
+    protected Long getNextIdLong(String nxtIdStmt) {
+        return getJdbcTemplate().queryForObject(nxtIdStmt, Long.class);
+    }
+
     public void setDistPoller(String distPoller) {
         this.distPoller = distPoller;
     }
