@@ -232,7 +232,6 @@ public class WillItUnmarshalIT {
         addFile(Source.CONFIG, "ifttt-config.xml", IfTttConfig.class, true, null);
         addFile(Source.CONFIG, "jasper-reports.xml", LocalJasperReports.class, false, null);
         addFile(Source.CONFIG, "javamail-configuration.xml", JavamailConfiguration.class, false, null);
-        addFile(Source.CONFIG, "jdbc-datacollection-config.xml", JdbcDataCollectionConfig.class, true, null);
         addFile(Source.CONFIG, "jms-northbounder-configuration.xml", JmsNorthbounderConfig.class, true, null);
         addFile(Source.CONFIG, "jmx-config.xml", JmxConfig.class, true, null);
         addFile(Source.CONFIG, "jmx-datacollection-config.xml", JmxDatacollectionConfig.class, true, null);
@@ -289,8 +288,6 @@ public class WillItUnmarshalIT {
         addFile(Source.EXAMPLE, "event-proxy/scriptd-configuration.xml", ScriptdConfiguration.class, false, null);
         addFile(Source.EXAMPLE, "event-proxy/vacuumd-configuration.xml", VacuumdConfiguration.class, false, null);
         addFile(Source.EXAMPLE, "groups.xml", Groupinfo.class, false, null);
-        addFile(Source.EXAMPLE, "hyperic-integration/imports-HQ.xml", Requisition.class, false, null);
-        addFile(Source.EXAMPLE, "hyperic-integration/imports-opennms-admin.xml", Requisition.class, false, null);
         addFile(Source.EXAMPLE, "jvm-datacollection/collectd-configuration.xml", CollectdConfiguration.class, false, null);
         addFile(Source.EXAMPLE, "jvm-datacollection/jmx-datacollection-config.d/activemq.xml", JmxDatacollectionConfig.class, false, null);
         addFile(Source.EXAMPLE, "jvm-datacollection/jmx-datacollection-config.d/cassandra.xml", JmxDatacollectionConfig.class, false, null);
@@ -318,7 +315,7 @@ public class WillItUnmarshalIT {
         addFile(Source.EXAMPLE, "viewsdisplay.xml", Viewinfo.class, false, null);
 
         // Add all event files
-        for (final File file : FileUtils.listFiles(new File(getDaemonEtcDirectory(), "events"),
+        for (final File file : FileUtils.listFiles(new File(getDaemonEtcDirectory(), "examples/events"),
                                                    new String[] { "xml" },
                                                    true)) {
             addFile(Source.ABSOLUTE, file.getPath(), Events.class, false, null);
@@ -350,6 +347,14 @@ public class WillItUnmarshalIT {
                     false, null);
         }
 
+        // Add all jdbc-datacollection configuration files
+        addFile(Source.CONFIG, "jdbc-datacollection-config.xml", JdbcDataCollectionConfig.class, false, null);
+        for (final File file : FileUtils.listFiles(new File(getDaemonEtcDirectory(), "jdbc-datacollection.d"),
+                                                   new String[] { "xml" },
+                                                   true)) {
+            addFile(Source.ABSOLUTE, file.getPath(), JdbcDataCollectionConfig.class, false, null);
+        }
+
         // Add all resource-types configuration files
         for (final File file : FileUtils.listFiles(new File(getDaemonEtcDirectory(), "resource-types.d"),
                                                    new String[] { "xml" },
